@@ -5,7 +5,7 @@ from django.apps import AppConfig
 from django.conf import settings
 from django.utils import timezone
 
-from basxbread.utils import get_concrete_instance
+from .tasks import run_action
 
 TRIGGER_PERIOD = getattr(settings, "TRIGGER_PERIOD", datetime.timedelta(hours=1))
 
@@ -58,30 +58,21 @@ def datachange_trigger(model, instance, type):
             model=contenttype, type=type, enable=True
         ):
             if type == "changed" and trigger.field and instance._old is not None:
-                if getattr(instance, trigger.field) == getattr(
-                    instance._old, trigger.field
+                fields = [i.strip() for i in trigger.field.split(",")]
+                if all(  # if none of the fields has changed, skip this trigger
+                    getattr(instance, field) == getattr(instance._old, field)
+                    for field in fields
                 ):
                     continue
             if trigger.filter.queryset.filter(pk=instance.pk).exists():
                 # delay execution a bit as the trigger may run immediately even though
                 # the current request has not finished (and therefore not commited to DB yet)
                 run_action.apply_async(
-                    (trigger.action.pk, instance._meta.label, instance.pk), countdown=5
+                    (trigger.action.pk, instance._meta.label, instance.pk), countdown=1
                 )
     instance._old = None
 
 
-@shared_task
-def run_action(action_pk, modelname, instance_pk):
-    from django.apps import apps
-
-    from .models import Action
-
-    get_concrete_instance(Action.objects.get(pk=action_pk)).run(
-        apps.get_model(modelname).objects.get(pk=instance_pk)
-    )
-
-
 def periodic_trigger():
 
     from .models import DateFieldTrigger
